@@ -1,46 +1,82 @@
-import abc
-from typing import Callable, Dict, Iterable, Optional, Sequence, Type, cast
+from typing import Any, Callable, Dict, Iterable, Optional, Sequence, Type, cast
 
 import click
 
+from ._context import Context
 from ._option_groups import OptionGroupMixin
 from ._sections import Section, SectionMixin
-from .constraints import ConstraintMixin, BoundConstraintSpec
+from .constraints import BoundConstraintSpec, ConstraintMixin
 
 
-class Command(ConstraintMixin, OptionGroupMixin, click.Command):
+class BaseCommand(click.Command):
+    """Base class for cloup commands.
+
+    * It back-ports a feature from Click v8.0-a1, i.e. the ``context_class``
+      class attribute, which is set to ``cloup.Context``.
+
+    * It adds a ``formatter_settings`` instance attribute.
+
+    .. versionadded:: 0.8.0
+    """
+    context_class: Type[Context] = Context
+
+    def __init__(
+        self, *args,
+        formatter_settings: Dict[str, Any] = {},
+        **kwargs,
+    ):
+        super().__init__(*args, **kwargs)
+        #: HelpFormatter options that are merged with ``Context.formatter_settings``
+        #: (eventually overriding some values).
+        self.formatter_settings = formatter_settings
+
+    def make_context(self, info_name, args, parent=None, **extra) -> Context:
+        for key, value in self.context_settings.items():
+            if key not in extra:
+                extra[key] = value
+
+        ctx = self.context_class(self, info_name=info_name, parent=parent, **extra)
+
+        with ctx.scope(cleanup=False):
+            self.parse_args(ctx, args)
+        return ctx
+
+    # Differently from Click, this doesn't indent the epilog.
+    def format_epilog(self, ctx, formatter):
+        if self.epilog:
+            formatter.write_paragraph()
+            formatter.write_epilog(self.epilog)
+
+    def format_help_text(self, ctx, formatter):
+        formatter.write_command_help_text(self)
+
+
+class Command(ConstraintMixin, OptionGroupMixin, BaseCommand):
     """
     A ``click.Command`` supporting option groups and constraints.
+
+    .. versionchanged:: 0.8.0
+        This class now inherits from :class:`cloup.BaseCommand`.
     """
+
     def __init__(
         self, *click_args,
+        formatter_settings: Dict[str, Any] = {},
         constraints: Sequence[BoundConstraintSpec] = (),
         show_constraints: bool = False,
-        align_option_groups: bool = True,
+        align_option_groups: Optional[bool] = None,
         **click_kwargs,
     ):
         super().__init__(
             *click_args,
+            formatter_settings=formatter_settings,
             constraints=constraints,
             show_constraints=show_constraints,
             align_option_groups=align_option_groups,
             **click_kwargs)
 
 
-class MultiCommand(SectionMixin, click.MultiCommand, metaclass=abc.ABCMeta):
-    """
-    A ``click.MultiCommand`` that allows to organize its subcommands in
-    multiple help sections and and whose subcommands are, by default, of type
-    :class:`cloup.Command`.
-
-    This class is just a :class:`click.MultiCommand` mixed with
-    :class:`SectionMixin`. See the docstring of the two superclasses for more
-    details.
-    """
-    pass
-
-
-class Group(SectionMixin, click.Group):
+class Group(SectionMixin, BaseCommand, click.Group):
     """
     A ``click.Group`` that allows to organize its subcommands in multiple help
     sections and and whose subcommands are, by default, of type
@@ -51,12 +87,17 @@ class Group(SectionMixin, click.Group):
     a ``section`` for the created subcommand can be specified.
 
     See the docstring of the two superclasses for more details.
+
+    .. versionchanged:: 0.8.0
+        This class now inherits from :class:`cloup.BaseCommand`.
     """
 
     def __init__(self, name: Optional[str] = None,
                  commands: Optional[Dict[str, click.Command]] = None,
                  sections: Iterable[Section] = (),
-                 align_sections: bool = True, **attrs):
+                 align_sections: Optional[bool] = None,
+                 formatter_settings: Dict[str, Any] = {},
+                 **attrs):
         """
         :param name: name of the command
         :param commands:
@@ -69,6 +110,7 @@ class Group(SectionMixin, click.Group):
         super().__init__(
             name=name, commands=commands,
             sections=sections, align_sections=align_sections,
+            formatter_settings=formatter_settings,
             **attrs)
 
     # MyPy complaints because the signature is not compatible with the parent
